==> moodle-1.4.3-pgsql.tgz: moodle/lang/de/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.3 (2004052500)


$string['april'] = 'April';
$string['august'] = 'August';
$string['calendar'] = 'Kalender';
$string['calendarheading'] = '$a Kalender';
$string['clickhide'] = 'Mit einem Klick verstecken';
$string['clickshow'] = 'Mit einem Klick anzeigen';
$string['confirmeventdelete'] = 'Sind Sie sicher, dass Sie diesen Termin lschen wollen?';
$string['courseevents'] = 'Kurstermine';
$string['dayview'] = 'Tagesansicht';
$string['daywithnoevents'] = 'Es gibt heute keine Termine';
$string['december'] = 'Dezember';
$string['default'] = 'Grundeinstellung';
$string['deleteevent'] = 'Termin lschen';
$string['detailedmonthview'] = 'Monatsgesamtansicht';
$string['durationminutes'] = 'Dauer in Minuten';
$string['durationnone'] = 'Ohne Zeitangabe';
$string['durationuntil'] = 'Bis';
$string['editevent'] = 'Termin bearbeiten';
$string['errorbeforecoursestart'] = 'Der angegebene Termin liegt vor dem Beginn des Kurses. Bitte korrigieren Sie den Eintrag.';
$string['errorinvaliddate'] = 'Ungltiges Datum';
$string['errorinvalidminutes'] = 'Geben Sie die Dauer inMinuten ein (Zahl zwischen 1 und 999)';
$string['errorinvalidrepeats'] = 'Geben Sie die Zahl ver Veranstaltungen ein (Zahl zwischen 1 und 99';
$string['errornodescription'] = 'Eine Beschreibung fr den Termin mu eingetragen werden.';
$string['errornoeventname'] = 'Eine Bezeichnung fr den Termin ist erforderlich.';
$string['eventdate'] = 'Datum';
$string['eventdescription'] = 'Beschreibung';
$string['eventduration'] = 'Dauer';
$string['eventendtime'] = 'Endzeitpunkt';
$string['eventinstanttime'] = 'Zeit';
$string['eventkind'] = 'Art des Termins';
$string['eventname'] = 'Name';
$string['eventrepeat'] = 'Wiederholungen';
$string['eventsfor'] = '$a Termine';
$string['eventstarttime'] = 'Startzeitpunkt';
$string['eventtime'] = 'Zeit';
$string['eventview'] = 'Details zu den Terminen';
$string['expired'] = 'Abgeschlossen';
$string['explain_lookahead'] = 'Mit dieser Einstellung legen Sie fest wie weit im voraus Termine angezeigt werden. Spter liegende Termine werden nicht als bevorstehende Termine angezeigt. Beachten Sie folgenden Hinweis: Es werden nur so viele Termine als bevorstehend angezeigt wie Sie sie in der Einstellung Hchstzahl der angezeigten bevorstehenden Termine festgelegt haben. Sie knnen also den Zeitraum fr den Termine angezeigt werden und die Hchstzahl der in dieser Zeit dargestellten Termine festlegen.';
$string['explain_maxevents'] = 'Diese Einstellung legt die Hchstzahl knftiger Termine fest, die angezeigt werden. Wenn Sie hier eine sehr groe Zahl eingeben, kann es sein, dass die Anzeige auf dem Bildschirm in einer sehr langen Liste erfolgt.';
$string['explain_startwday'] = 'Diese Einstellung legt die Art der Monatsdarstellung des Kalenders fest. ';
$string['explain_timeformat'] = 'Mit dieser Einstellung whlen Sie das Format der Zeitanzeige (12/24-Stunden-Anzeige). Die Default-Einstellung bernimmt das format der Zeitanzeige aus der Sprachversion, die Sie fr Ihre Seite gewhlt haben.';
$string['february'] = 'Februar';
$string['fri'] = 'Fr';
$string['friday'] = 'Freitag';
$string['globalevents'] = 'Globale Termine';
$string['gotocalendar'] = 'Zum Kalender';
$string['groupevents'] = 'Gruppen- termine';
$string['hidden'] = 'versteckt';
$string['january'] = 'Januar';
$string['july'] = 'Juli';
$string['june'] = 'Juni';
$string['manyevents'] = '$a Termine';
$string['march'] = 'Mrz';
$string['may'] = 'Mai';
$string['mon'] = 'Mo';
$string['monday'] = 'Montag';
$string['monthlyview'] = 'Monatsbersicht';
$string['newevent'] = 'Neuer Termin';
$string['noupcomingevents'] = 'Es gibt keine weiteren Termine';
$string['november'] = 'November';
$string['october'] = 'Oktober';
$string['oneevent'] = '1 Termin';
$string['pref_lookahead'] = 'Terminvorschau';
$string['pref_maxevents'] = 'Hchstzahl der bevorstehenden Termine';
$string['pref_startwday'] = 'Erster Tag der Woche';
$string['pref_timeformat'] = 'Format der Zeitanzeige';
$string['preferences'] = 'Einstellungen';
$string['preferences_available'] = 'Ihre persnlichen Einstellungen';
$string['repeatnone'] = 'Keine Wiederholungen';
$string['repeatweeksl'] = 'Wchentliche Wiederholung, automatische Erstellung';
$string['repeatweeksr'] = 'Termine';
$string['sat'] = 'Sa';
$string['saturday'] = 'Samstag';
$string['september'] = 'September';
$string['shown'] = 'angezeigt';
$string['spanningevents'] = 'Termine in Vorbereitung';
$string['sun'] = 'So';
$string['sunday'] = 'Sonntag';
$string['thu'] = 'Do';
$string['thursday'] = 'Donnerstag';
$string['timeformat_12'] = '12-Stunden-Anzeige';
$string['timeformat_24'] = '24-Stunden-Anzeige';
$string['today'] = 'Heute';
$string['tomorrow'] = 'Morgen';
$string['tt_deleteevent'] = 'Termin lschen';
$string['tt_editevent'] = 'Termin bearbeiten';
$string['tt_hidecourse'] = 'Kurstermine werden angezeigt (klicken Sie hier ,um sie zu verstecken).';
$string['tt_hideglobal'] = 'Globale Termine werden angezeigt (klicken Sie hier, um sie zu verstecken ).';
$string['tt_hidegroups'] = 'Gruppentermine werden angezeigt (klicken Sie hier, um sie zu verstecken).';
$string['tt_hideuser'] = 'Teilnehmertermine werden angezeigt (klicken Sie hier, um sie zu verstecken).';
$string['tt_showcourse'] = 'Kurstermine werden verborgen (klicken Sie hier, um sie anzuzeigen).';
$string['tt_showglobal'] = 'Globale Termine werden verborgen (klicken Sie hier, um sie anzuzeigen).';
$string['tt_showgroups'] = 'Gruppentermine werden verborgen (klicken Sie hier, um sie anzuzeigen).';
$string['tt_showuser'] = 'Teilnehmertermine werden verborgen (klicken Sie hier, um sie anzuzeigen).';
$string['tue'] = 'Di';
$string['tuesday'] = 'Dienstag';
$string['typecourse'] = 'Kurstermine';
$string['typegroup'] = 'Gruppentermine';
$string['typesite'] = 'Seitentermine';
$string['typeuser'] = 'Teilnehmerterm.';
$string['upcomingevents'] = 'Bevorstehende Termine';
$string['userevents'] = 'Teilnehmer- termine';
$string['wed'] = 'Mi';
$string['wednesday'] = 'Mittwoch';
$string['yesterday'] = 'Gestern';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/de/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 ALPHA (2005043000)


$string['calendar'] = 'Kalender';
$string['calendarheading'] = '$a Kalender';
$string['clickhide'] = 'Mit einem Klick verstecken';
$string['clickshow'] = 'Mit einem Klick anzeigen';
$string['confirmeventdelete'] = 'Sind Sie sicher, dass Sie diesen Termin lschen wollen?';
$string['courseevents'] = 'Kurstermine';
$string['dayview'] = 'Tagesansicht';
$string['daywithnoevents'] = 'Es gibt heute keine Termine';
$string['default'] = 'Grundeinstellung';
$string['deleteevent'] = 'Termin lschen';
$string['detailedmonthview'] = 'Monatsgesamtansicht';
$string['durationminutes'] = 'Dauer in Minuten';
$string['durationnone'] = 'Ohne Zeitangabe';
$string['durationuntil'] = 'Bis';
$string['editevent'] = 'Termin bearbeiten';
$string['errorbeforecoursestart'] = 'Der angegebene Termin liegt vor dem Beginn des Kurses. Bitte korrigieren Sie den Eintrag.';
$string['errorinvaliddate'] = 'Ungltiges Datum';
$string['errorinvalidminutes'] = 'Geben Sie die Dauer in Minuten ein (Zahl zwischen 1 und 999)';
$string['errorinvalidrepeats'] = 'Geben Sie die Zahl der Veranstaltungen ein (Zahl zwischen 1 und 99';
$string['errornodescription'] = 'Eine Beschreibung fr den Termin mu eingetragen werden.';
$string['errornoeventname'] = 'Eine Bezeichnung fr den Termin ist erforderlich.';
$string['eventdate'] = 'Datum';
$string['eventdescription'] = 'Beschreibung';
$string['eventduration'] = 'Dauer';
$string['eventendtime'] = 'Endzeitpunkt';
$string['eventinstanttime'] = 'Zeit';
$string['eventkind'] = 'Art des Termins';
$string['eventname'] = 'Name';
$string['eventrepeat'] = 'Wiederholungen';
$string['eventsfor'] = '$a Termine';
$string['eventstarttime'] = 'Startzeitpunkt';
$string['eventtime'] = 'Zeit';
$string['eventview'] = 'Details zu den Terminen';
$string['expired'] = 'Abgeschlossen';
$string['explain_lookahead'] = 'Mit dieser Einstellung legen Sie fest wie weit im voraus Termine angezeigt werden. Spter liegende Termine werden nicht als bevorstehende Termine angezeigt. Beachten Sie folgenden Hinweis: Es werden nur so viele Termine als bevorstehend angezeigt wie Sie sie in der Einstellung Hchstzahl der angezeigten bevorstehenden Termine festgelegt haben. Sie knnen also den Zeitraum fr den Termine angezeigt werden und die Hchstzahl der in dieser Zeit dargestellten Termine festlegen.';
$string['explain_maxevents'] = 'Diese Einstellung legt die Hchstzahl knftiger Termine fest, die angezeigt werden. Wenn Sie hier eine sehr groe Zahl eingeben, kann es sein, dass die Anzeige auf dem Bildschirm in einer sehr langen Liste erfolgt.';
$string['explain_persistflt'] = 'Wenn Sie diese Einstellung aktivieren, prft moodle bei jedem Login die Filtereinstellungen fr Termine und aktualisiert sie.';
$string['explain_startwday'] = 'Diese Einstellung legt die Art der Monatsdarstellung des Kalenders fest. ';
$string['explain_timeformat'] = 'Mit dieser Einstellung whlen Sie das Format der Zeitanzeige (12/24-Stunden-Anzeige). Die Default-Einstellung bernimmt das Format der Zeitanzeige aus der Sprachversion, die Sie fr Ihre Seite gewhlt haben.';
$string['fri'] = 'Fr';
$string['friday'] = 'Freitag';
$string['globalevents'] = 'Globale Termine';
$string['gotocalendar'] = 'Zum Kalender';
$string['groupevents'] = 'Gruppen- termine';
$string['hidden'] = 'versteckt';
$string['manyevents'] = '$a Termine';
$string['mon'] = 'Mo';
$string['monday'] = 'Montag';
$string['monthlyview'] = 'Monatsbersicht';
$string['newevent'] = 'Neuer Termin';
$string['noupcomingevents'] = 'Es gibt keine weiteren Termine';
$string['oneevent'] = '1 Termin';
$string['pref_lookahead'] = 'Terminvorschau';
$string['pref_maxevents'] = 'Hchstzahl der bevorstehenden Termine';
$string['pref_persistflt'] = 'An Filtereinstellungen erinnern';
$string['pref_startwday'] = 'Erster Tag der Woche';
$string['pref_timeformat'] = 'Format der Zeitanzeige';
$string['preferences'] = 'Einstellungen';
$string['preferences_available'] = 'Ihre persnlichen Einstellungen';
$string['repeateditall'] = 'Vernderungen fr alle $a Termine dieser Reihe bearbeiten';
$string['repeateditthis'] = 'Vernderungen nur an diesem einen Termin vornehmen';
$string['repeatnone'] = 'Keine Wiederholungen';
$string['repeatweeksl'] = 'Wchentliche Wiederholung, automatische Erstellung';
$string['repeatweeksr'] = 'Termine';
$string['sat'] = 'Sa';
$string['saturday'] = 'Samstag';
$string['shown'] = 'angezeigt';
$string['spanningevents'] = 'Termine in Vorbereitung';
$string['sun'] = 'So';
$string['sunday'] = 'Sonntag';
$string['thu'] = 'Do';
$string['thursday'] = 'Donnerstag';
$string['timeformat_12'] = '12-Stunden-Anzeige';
$string['timeformat_24'] = '24-Stunden-Anzeige';
$string['today'] = 'Heute';
$string['tomorrow'] = 'Morgen';
$string['tt_deleteevent'] = 'Termin lschen';
$string['tt_editevent'] = 'Termin bearbeiten';
$string['tt_hidecourse'] = 'Kurstermine werden angezeigt (klicken Sie hier ,um sie zu verstecken).';
$string['tt_hideglobal'] = 'Globale Termine werden angezeigt (klicken Sie hier, um sie zu verstecken ).';
$string['tt_hidegroups'] = 'Gruppentermine werden angezeigt (klicken Sie hier, um sie zu verstecken).';
$string['tt_hideuser'] = 'Teilnehmertermine werden angezeigt (klicken Sie hier, um sie zu verstecken).';
$string['tt_showcourse'] = 'Kurstermine werden verborgen (klicken Sie hier, um sie anzuzeigen).';
$string['tt_showglobal'] = 'Globale Termine werden verborgen (klicken Sie hier, um sie anzuzeigen).';
$string['tt_showgroups'] = 'Gruppentermine werden verborgen (klicken Sie hier, um sie anzuzeigen).';
$string['tt_showuser'] = 'Teilnehmertermine werden verborgen (klicken Sie hier, um sie anzuzeigen).';
$string['tue'] = 'Di';
$string['tuesday'] = 'Dienstag';
$string['typecourse'] = 'Kurstermine';
$string['typegroup'] = 'Gruppentermine';
$string['typesite'] = 'Seitentermine';
$string['typeuser'] = 'Teilnehmerterm.';
$string['upcomingevents'] = 'Bald aktuell ...';
$string['userevents'] = 'Teilnehmer- termine';
$string['wed'] = 'Mi';
$string['wednesday'] = 'Mittwoch';
$string['yesterday'] = 'Gestern';
$string['youcandeleteallrepeats'] = 'Dieser Termin ist Teil einer ganzen Reihe von Terminen. Sie knnen diesen einzelnen Termin oder alle a Termine dieser Reihe auf einmal lschen.';

?>
